@@ -1,14 +1,14 @@
 __all__ = ['webservice', 'webquery', 'exceptions',
-           'wcat', 'wcated', 'googlebooks', 'isbndb',
+           'wcat', 'wcated', 'googlebooks', 'isbndb', 'openl',
            'WSHTTPError', 'WSURLError', 'WQDataNotFoundError',
            'WQServiceIsDownError', 'WPDataWrongShapeError',
            'WPNotValidMetadataError', 'Metadata', 'stdmeta',
            'normalize_space', 'WEBService', 'WEBQuery', 'WCATQuery',
-           'WCATEdQuery', 'GOOBQuery', 'ISBNDBQuery',
+           'WCATEdQuery', 'GOOBQuery', 'ISBNDBQuery', 'OPENLQuery',
            'WSHTTPError', 'WSURLError',
            'WQDataNotFoundError', 'WQServiceIsDownError',
            'WPDataWrongShapeError', 'WPNotValidMetadataError',
-           'WPNotImplementedError'
+           'WPRecordMappingError', 'WPNotImplementedError'
            ]
 
 
@@ -18,9 +18,10 @@ from .wcat import WCATQuery
 from .wcated import WCATEdQuery
 from .googlebooks import GOOBQuery
 from .isbndb import ISBNDBQuery
+from .openl import OPENLQuery
 from .exceptions import (WSHTTPError, WSURLError,
                          WQDataNotFoundError, WQServiceIsDownError,
                          WPDataWrongShapeError, WPNotValidMetadataError,
-                         WPNotImplementedError)
+                         WPRecordMappingError, WPNotImplementedError)
 from .data import Metadata, stdmeta
 from .helpers import normalize_space
