@@ -52,12 +52,24 @@ class WPDataWrongShapeError(ISBNToolsDevException):
     message = "the data hasn't the expected format"
 
 
+class WPDataNotFoundError(ISBNToolsDevException):
+    """ Exception raised when the data isn't availabe at the service
+    """
+    message = "the data isn't available at this service"
+
+
 class WPNotValidMetadataError(ISBNToolsDevException):
     """ Exception raised when the metadata hasn't the expected format
     """
     message = "the metadata hasn't the expected format"
 
 
+class WPRecordMappingError(ISBNToolsDevException):
+    """ Exception raised when the mapping records -> canonical doesn't work
+    """
+    message = "the mapping records -> canonical doesn't work"
+
+
 class WPNotImplementedError(ISBNToolsDevException):
     """ Exception raised when the methods wasn't implemented yet!
     """
