@@ -4,7 +4,8 @@
 import logging
 from .webquery import WEBQuery
 from .data import stdmeta
-from .exceptions import WPDataWrongShapeError
+from .exceptions import (WPDataWrongShapeError, WPDataNotFoundError,
+                         WPRecordMappingError)
 
 UA = 'isbntools (gzip)'
 SERVICE_URL = 'https://www.googleapis.com/books/v1/volumes?q=isbn+%s&fields='\
@@ -43,21 +44,25 @@ class GOOBQuery(WEBQuery):
                 logger.debug('WPDataWrongShapeError for % with data %s' %
                              (self.isbn, extra))
             except:
-                pass
-            raise WPDataWrongShapeError(self.isbn)
+                raise WPDataWrongShapeError(self.isbn)
+            raise WPDataNotFoundError(self.isbn)
 
         # canonical:
         # -> ISBN-13, Title, Authors, Publisher, Year, Language
-        canonical = {}
-        canonical['ISBN-13'] = unicode(self.isbn)
-        canonical['Title'] = records['title'].replace(' :', ':')
-        canonical['Authors'] = records.get('authors', [])
-        canonical['Publisher'] = records.get('publisher', u'')
-        if 'publishedDate' in records and len(records['publishedDate']) >= 4:
-            canonical['Year'] = records['publishedDate'][0:4]
-        else:         # pragma: no cover
-            canonical['Year'] = u''
-        canonical['Language'] = records['language']
+        try:
+            canonical = {}
+            canonical['ISBN-13'] = unicode(self.isbn)
+            canonical['Title'] = records.get('title', u'').replace(' :', ':')
+            canonical['Authors'] = records.get('authors', [])
+            canonical['Publisher'] = records.get('publisher', u'')
+            if 'publishedDate' in records \
+               and len(records['publishedDate']) >= 4:
+                canonical['Year'] = records['publishedDate'][0:4]
+            else:         # pragma: no cover
+                canonical['Year'] = u''
+            canonical['Language'] = records.get('language', u'')
+        except:
+            raise WPRecordMappingError(self.isbn)
         # call stdmeta for extra cleanning and validation
         return stdmeta(canonical)
 
