@@ -4,7 +4,8 @@
 import logging
 from .webquery import WEBQuery
 from .data import stdmeta
-from .exceptions import WPDataWrongShapeError
+from .exceptions import (WPDataWrongShapeError, WPDataNotFoundError,
+                         WPRecordMappingError)
 
 
 UA = 'isbntools (gzip)'
@@ -43,18 +44,21 @@ class WCATQuery(WEBQuery):
                 logger.debug('WPDataWrongShapeError for % with data %s' %
                              (self.isbn, extra))
             except:
-                pass
-            raise WPDataWrongShapeError(self.isbn)
+                raise WPDataWrongShapeError(self.isbn)
+            raise WPDataNotFoundError(self.isbn)
 
         # canonical:
         # -> ISBN-13, Title, Authors, Publisher, Year, Language
-        canonical = {}
-        canonical['ISBN-13'] = unicode(self.isbn)
-        canonical['Title'] = records['title'].replace(' :', ':')
-        canonical['Authors'] = [records.get('author', u'')]
-        canonical['Publisher'] = records['publisher']
-        canonical['Year'] = records['year']
-        canonical['Language'] = records['lang']
+        try:
+            canonical = {}
+            canonical['ISBN-13'] = unicode(self.isbn)
+            canonical['Title'] = records.get('title', u'').replace(' :', ':')
+            canonical['Authors'] = [records.get('author', u'')]
+            canonical['Publisher'] = records.get('publisher', u'')
+            canonical['Year'] = records.get('year', u'')
+            canonical['Language'] = records.get('lang', u'')
+        except:
+            raise WPRecordMappingError(self.isbn)
         # call stdmeta for extra cleanning and validation
         return stdmeta(canonical)
 
